Index: src/mips/builtins-mips.cc |
diff --git a/src/mips/builtins-mips.cc b/src/mips/builtins-mips.cc |
index 93ba3a0098876362d52b1617990cd06e5f244799..229399ee3dc824a72de19b38e11f8062ab4f7a7e 100644 |
--- a/src/mips/builtins-mips.cc |
+++ b/src/mips/builtins-mips.cc |
@@ -79,12 +79,12 @@ void Builtins::Generate_Adaptor(MacroAssembler* masm, |
// Load the built-in InternalArray function from the current context. |
static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
Register result) { |
// Load the global context. |
__ lw(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ lw(result, |
- FieldMemOperand(result, GlobalObject::kGlobalContextOffset)); |
- // Load the InternalArray function from the global context. |
+ FieldMemOperand(result, GlobalObject::kNativeContextOffset)); |
+ // Load the InternalArray function from the native context. |
__ lw(result, |
MemOperand(result, |
Context::SlotOffset( |
@@ -94,12 +94,12 @@ static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
// Load the built-in Array function from the current context. |
static void GenerateLoadArrayFunction(MacroAssembler* masm, Register result) { |
// Load the global context. |
__ lw(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ lw(result, |
- FieldMemOperand(result, GlobalObject::kGlobalContextOffset)); |
- // Load the Array function from the global context. |
+ FieldMemOperand(result, GlobalObject::kNativeContextOffset)); |
+ // Load the Array function from the native context. |
__ lw(result, |
MemOperand(result, |
Context::SlotOffset(Context::ARRAY_FUNCTION_INDEX))); |
@@ -1432,7 +1432,7 @@ void Builtins::Generate_FunctionCall(MacroAssembler* masm) { |
const int kGlobalIndex = |
Context::kHeaderSize + Context::GLOBAL_INDEX * kPointerSize; |
__ lw(a2, FieldMemOperand(cp, kGlobalIndex)); |
- __ lw(a2, FieldMemOperand(a2, GlobalObject::kGlobalContextOffset)); |
+ __ lw(a2, FieldMemOperand(a2, GlobalObject::kNativeContextOffset)); |
__ lw(a2, FieldMemOperand(a2, kGlobalIndex)); |
__ lw(a2, FieldMemOperand(a2, GlobalObject::kGlobalReceiverOffset)); |
@@ -1625,7 +1625,7 @@ void Builtins::Generate_FunctionApply(MacroAssembler* masm) { |
const int kGlobalOffset = |
Context::kHeaderSize + Context::GLOBAL_INDEX * kPointerSize; |
__ lw(a0, FieldMemOperand(cp, kGlobalOffset)); |
- __ lw(a0, FieldMemOperand(a0, GlobalObject::kGlobalContextOffset)); |
+ __ lw(a0, FieldMemOperand(a0, GlobalObject::kNativeContextOffset)); |
__ lw(a0, FieldMemOperand(a0, kGlobalOffset)); |
__ lw(a0, FieldMemOperand(a0, GlobalObject::kGlobalReceiverOffset)); |
@@ -79,12 +79,12 @@ void Builtins::Generate_Adaptor(MacroAssembler* masm, |
static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
Register result) { |
- // Load the global context. |
+ // Load the native context. |
__ lw(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ lw(result, |
@@ -94,12 +94,12 @@ static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
// Load the built-in Array function from the current context. |
static void GenerateLoadArrayFunction(MacroAssembler* masm, Register result) { |
- // Load the global context. |
+ // Load the native context. |
__ lw(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ lw(result, |